#Copyright (c) Members of the EGEE Collaboration. 2004.
#See http://public.eu-egee.org/partners/ for details on the copyright holders.
#For license conditions see the license file or
#http://www.eu-egee.org/license.html

package Globus::RLS;

use 5.000;
use strict;
use Carp;

require Exporter;
require DynaLoader;
use AutoLoader;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
@ISA = qw(Exporter
	DynaLoader);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use Globus::RLS ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
%EXPORT_TAGS = ( 'all' => [ qw(
	
) ] );

@EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

@EXPORT = qw(
	
);

$VERSION = '0.01';

sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.

    my $constname;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    croak "&Globus::RLS::constant not defined" if $constname eq 'constant';
    my ($error, $val) = constant($constname);
    if ($error) { croak $error; }
    {
	no strict 'refs';
	# Fixed between 5.005_53 and 5.005_61
#XXX	if ($] >= 5.00561) {
#XXX	    *$AUTOLOAD = sub () { $val };
#XXX	}
#XXX	else {
	    *$AUTOLOAD = sub { $val };
#XXX	}
    }
    goto &$AUTOLOAD;
}

bootstrap Globus::RLS $VERSION;

# Preloaded methods go here.

# Below is stub documentation for your module. You'd better edit it!

=pod

=head1 NAME

Globus::RLS - Perl extension for Globus RLS client

=head1 SYNOPSIS

  use Globus::RLS;

=head1 DESCRIPTION

Globus RLS client API for accessing Globus RLS server.

For more information on the interface see L<http://www.isi.edu/%7Eannc/rls/doc/client/index.html>.

=head1 METHODS

Methods call I<die> in case of fatal error and call I<warn> in case of recoverable errors. If there was a fault, return value is not equal to 0 (zero). Methods call I<die> when format of input parameters are not correct. The fault string and details are added to the I<die> or I<warn> message.

=over 4

=cut

#######################################################################
#######################################################################
# Constructor/Activation
#

=pod

=back

=head2 Constructor/Activation

=over 4

=item B<new()>

Constructor method for an RLS client.

B<Return value:>
    $rv is a reference to an RLS object, if successful. Otherwise, the method I<dies>.

B<Example:>

    my $rls = Globus:RLS->new();

=cut

sub new () {
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self = {};
    bless ($self, $class);

    _globus_module_activate_common();
	_globus_module_activate_io();
	_globus_module_activate_rls_client();

    return $self;
}

#######################################################################
#######################################################################
# Connection Management
#

#void 	globus_rls_client_certificate (char *certfile, char *keyfile)
#void 	globus_rls_client_proxy_certificate (char *proxy)

=pod

=back

=head2 Connection Management

=over 4

=item B<globus_rls_client_connect($endpoint)>

Open a connection to the Globus RLS server pointed by $endpoint.

B<Return value:>
    No value returned. In case of failure, the method I<dies>.

B<Example:>

    $rls->globus_rls_client_connect("rls://rls_server.example.org");

=cut

#globus_result_t 	globus_rls_client_connect (char *url, globus_rls_handle_t **h)
sub globus_rls_client_connect() {
  my $self = shift;
  my $endpoint = shift;

  my $handle = _globus_rls_client_connect($endpoint);
  $self->{handle} = $handle;

  return;
}

=pod

=item B<globus_rls_client_close()>

Close the connection to the Globus RLS server.

B<Return value:>
    No value returned. In case of failure, the method I<dies>.

B<Example:>

    $rls->globus_rls_client_close();

=cut

#globus_result_t 	globus_rls_client_close (globus_rls_handle_t *h)
sub globus_rls_client_close() {
  my $self = shift;

  _globus_rls_client_close($self->{handle});
  return;
}

#int 	globus_rls_client_get_timeout ()

=pod

=item B<globus_rls_client_get_timeout()>

Get timeout for IO calls to RLS server. If 0 IO calls do not timeout. The default is 30 seconds.

B<Return value:>
    $timeout is the timeout in seconds.

B<Example:>

    $timeout = $rls->globus_rls_client_get_timeout();

=cut

sub globus_rls_client_get_timeout() {
  my $self = shift;

  return _globus_rls_client_get_timeout();
}

=pod

=item B<globus_rls_client_set_timeout($timeout)>

Set timeout for IO calls to RLS server to be $timeout seconds.

B<Return value:>
    No value returned.

B<Example:>

    $rls->globus_rls_client_set_timeout(60);

=cut

#void 	globus_rls_client_set_timeout (int seconds)
sub globus_rls_client_set_timeout() {
  my $self = shift;
  my $seconds = shift;

  _globus_rls_client_set_timeout($seconds);
}

#######################################################################
#######################################################################
# LRC Operations
#

=pod

=back

=head2 LRC Operations

=over 4

=item B<globus_rls_client_lrc_attr_add($object, $attrname, $objtype, $attrtype, $val)>

Add an attribute to an object in the LRC database.

The $object is the name of an LFN (Logic File Name) or PFN (Physical File Name) previously created with L<globus_rls_client_lrc_create()>. The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants. The $attrtype parameter is one of the "globus_rls_attr_type_date", "globus_rls_attr_type_flt", "globus_rls_attr_type_int", "globus_rls_attr_type_str" constants. The $val input parameter is the value of the attribute to be assigned to the object.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_attr_add("MyLFN", "size", "globus_rls_obj_lrc_lfn", "globus_rls_attr_type_int", 1000);

=cut

#globus_result_t 	globus_rls_client_lrc_attr_add (globus_rls_handle_t *h, char *key, globus_rls_attribute_t *attr)
sub globus_rls_client_lrc_attr_add() {
  my $self = shift;
  my $object = shift;
  my $attrname = shift;
  my $objtype = shift;
  my $attrtype = shift;
  my $val = shift;

  return _globus_rls_client_lrc_attr_add($self->{handle},$object,$attrname,$objtype,$attrtype,$val);
}

=pod

=item B<globus_rls_client_lrc_attr_add_bulk($handle, $listofelements)>

Bulk add attributes to objects in the LRC database.

B<Note:>

    Developed, but test failed, due to some globus client problem!!
    Needs further investigation.

=cut

#globus_result_t 	globus_rls_client_lrc_attr_add_bulk (globus_rls_handle_t *h, globus_list_t *attr_obj_list, globus_list_t **str2bulk_list)
sub globus_rls_client_lrc_attr_add_bulk() {
  my $self = shift;
  my $handle = shift;
  my $listelements = shift;

  return _globus_rls_client_lrc_attr_add_bulk($handle,$listelements);
}

=pod

=item B<globus_rls_client_lrc_attr_create($attrname, $objtype, $attrtype)>

Define new attribute in LRC database.

The $attrname is the name of attribute to be created. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants. The $attrtype parameter is one of the "globus_rls_attr_type_date", "globus_rls_attr_type_flt", "globus_rls_attr_type_int", "globus_rls_attr_type_str" constants. The $val input parameter is the value of the attribute to be assigned to the object.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_attr_create("size", "globus_rls_obj_lrc_lfn", "globus_rls_attr_type_int");

=cut

#globus_result_t 	globus_rls_client_lrc_attr_create (globus_rls_handle_t *h, char *name, globus_rls_obj_type_t objtype, globus_rls_attr_type_t type)
sub globus_rls_client_lrc_attr_create() {
  my $self = shift;
  my $attrname = shift;
  my $objtype = shift;
  my $attrtype = shift;

  return _globus_rls_client_lrc_attr_create($self->{handle},$attrname,$objtype,$attrtype);
}

=pod

=item B<globus_rls_client_lrc_attr_delete($attrname,$objtype,$clearvalues)>

Undefine attribute in LRC database.

The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants. If $clearvalues is evaluated as true then any values for this attribute are first removed from the objects they're associated with. If $clearvalues is false and any values exist then method fails.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rls->globus_rls_client_lrc_attr_delete("size","globus_rls_obj_lrc_lfn",1);

=cut

#globus_result_t 	globus_rls_client_lrc_attr_delete (globus_rls_handle_t *h, char *name, globus_rls_obj_type_t objtype, globus_bool_t clearvalues)
sub globus_rls_client_lrc_attr_delete() {
  my $self = shift;
  my $attrname = shift;
  my $objtype = shift;
  my $clearvalues = shift;

  return _globus_rls_client_lrc_attr_delete($self->{handle},$attrname,$objtype,$clearvalues);
}

=pod

=item B<globus_rls_client_lrc_attr_get($attrname,$objtype)>

Return definitions of attributes in LRC database.

The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list is a list of references to hashes storing attributes with the following keys: "NAME", "OBJTYPE", "TYPE".

B<Example:>

    ($rv, @list) = $rls->globus_rls_client_lrc_attr_get("size","globus_rls_obj_lrc_lfn");
    while ( $attrib = shift(@list) and defined($attrib)) {
      foreach $key ("NAME","OBJTYPE","TYPE") {
        print $key," : ",$attrib->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_attr_get (globus_rls_handle_t *h, char *name, globus_rls_obj_type_t objtype, globus_list_t **attr_list)
sub globus_rls_client_lrc_attr_get() {
  my $self = shift;
  my $attrname = shift;
  my $objtype = shift;

  return _globus_rls_client_lrc_attr_get($self->{handle},$attrname,$objtype);
}

=pod

=item B<globus_rls_client_lrc_attr_modify($object,$attrname,$objtype,$attrtype,$val)>

Modify an attribute value.

The $object is the name of an LFN (Logic File Name) or PFN (Physical File Name) previously created with L<globus_rls_client_lrc_create()>. The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants. The $attrtype parameter is one of the "globus_rls_attr_type_date", "globus_rls_attr_type_flt", "globus_rls_attr_type_int", "globus_rls_attr_type_str" constants. The $val input parameter is the new value of the attribute to be assigned to the object.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_attr_modify("MyLFN", "size", "globus_rls_obj_lrc_lfn", "globus_rls_attr_type_int", 2000);

=cut

#globus_result_t 	globus_rls_client_lrc_attr_modify (globus_rls_handle_t *h, char *key, globus_rls_attribute_t *attr)
sub globus_rls_client_lrc_attr_modify() {
  my $self = shift;
  my $object = shift;
  my $attrname = shift;
  my $objtype = shift;
  my $attrtype = shift;
  my $val = shift;

  return _globus_rls_client_lrc_attr_modify($self->{handle},$object,$attrname,$objtype,$attrtype,$val);
}

=pod

=item B<globus_rls_client_lrc_attr_remove($object,$attrname,$objtype)>

Remove an attribute from an object (LFN or PFN) in the LRC database.

The $object is the name of an LFN (Logic File Name) or PFN (Physical File Name) previously created with L<globus_rls_client_lrc_create()>. The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_attr_remove("MyLFN", "size", "globus_rls_obj_lrc_lfn");

=cut

#globus_result_t 	globus_rls_client_lrc_attr_remove (globus_rls_handle_t *h, char *key, globus_rls_attribute_t *attr)
sub globus_rls_client_lrc_attr_remove() {
  my $self = shift;
  my $object = shift;
  my $attrname = shift;
  my $objtype = shift;

  return _globus_rls_client_lrc_attr_remove($self->{handle},$object,$attrname,$objtype);
}

=pod

=item B<globus_rls_client_lrc_attr_search($attrname,$objtype,$op,$attrtype,$val,$offset,$reslimit)>

Search for objects (LFNs or PFNs) in a LRC database that have the specified attribute whose value matches a boolean expression.

The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants. The $op is the operand represented as string that can be on of the followings: "=", "!=", ">", ">=", "<", "<=", "like". The $attrtype parameter is one of the "globus_rls_attr_type_date", "globus_rls_attr_type_flt", "globus_rls_attr_type_int", "globus_rls_attr_type_str" constants. The $val input parameter is the value of the attribute. Value is evaluated on the right side in the boolean expression during search.

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes containing object parameters with the specified attribute. Keys to hashes are "KEY", "ATTR.NAME", "ATTR.TYPE", "ATTR.VAL", "ATTR.OBJTYPE", "ERRMSG", "RC". RC is the return status of the actual object. If it is not equal to zero "ERRMSG" is specified.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_lrc_attr_search ("size", "globus_rls_obj_lrc_lfn", ">", "globus_rls_attr_type_int", 1000, 0, 0);
    while ( $attrib = shift(@list) and defined($attrib)) {
      foreach $key ("KEY", "ATTR.NAME", "ATTR.TYPE", "ATTR.VAL", "ATTR.OBJTYPE", "ERRMSG", "RC") {
        print $key," : ",$attrib->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_attr_search (globus_rls_handle_t *h, char *name, globus_rls_obj_type_t objtype, globus_rls_attr_op_t op, globus_rls_attribute_t *operand1, globus_rls_attribute_t *operand2, int *offset, int reslimit, globus_list_t **attr_obj_list)
sub globus_rls_client_lrc_attr_search() {
  my $self = shift;
  my $attrname = shift;
  my $objtype = shift;
  my $op = shift;
  my $attrtype = shift;
  my $val = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_lrc_attr_search($self->{handle},$attrname,$objtype,$op,$attrtype,$val,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_lrc_attr_value_get($object, $attrname, $objtype)>

Return attributes in LRC database for specified object (LFN or PFN).

The $object is the name of an LFN (Logic File Name) or PFN (Physical File Name) previously created with L<globus_rls_client_lrc_create()>. The $attrname is the name of attribute previously created with L<globus_rls_client_lrc_attr_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing object parameters with the specified value. Keys to hashes are "NAME", "TYPE", "VAL", "OBJTYPE".

B<Example:>

    ($rv, @list) = $rls->globus_rls_client_lrc_attr_value_get("MyLFN", "size", "globus_rls_obj_lrc_lfn");
    while ( $attrib = shift(@list) and defined($attrib)) {
      foreach $key ("NAME", "TYPE", "VAL", "OBJTYPE") {
        print $key," : ",$attrib->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_attr_value_get (globus_rls_handle_t *h, char *key, char *name, globus_rls_obj_type_t objtype, globus_list_t **attr_list)

sub globus_rls_client_lrc_attr_value_get() {
  my $self = shift;
  my $object = shift;
  my $attrname = shift;
  my $objtype = shift;

  _globus_rls_client_lrc_attr_value_get($self->{handle},$object,$attrname,$objtype);
}

=pod

=item B<globus_rls_client_lrc_add($lfn, $pfn)>

Add mapping of PFN to an existing LFN.

The $lfn is the name of an LFN (Logic File Name) previously created with L<globus_rls_client_lrc_create()>. The $pfn is the name of a PFN (Physical File Name).

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_add("MyLFN", "aPFN");

=cut

#globus_result_t 	globus_rls_client_lrc_add (globus_rls_handle_t *h, char *lfn, char *pfn)
sub globus_rls_client_lrc_add() {
  my $self = shift;
  my $lfn = shift;
  my $pfn = shift;

  return _globus_rls_client_lrc_add($self->{handle},$lfn,$pfn);
}

=pod

=item B<globus_rls_client_lrc_add_bulk(\@lfnpfnlist)>

Bulk add LFN,PFN mappings in LRC database. LFNs must already exist.

The \@lfnpfnlist is reference to array containing the name of an LFN (Logical File Name) and the name of a PFN (Physical File Name) one ofter the other.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing failed updates. Keys to hashes are "STR2.S1" containing LFN, "STR2.S2" containing PFN, "ERRMSG" containing error message and "RC" containing result code.

B<Example:>

    $lfnpfnlist = ["MyLFN", "PFNa", "MyLFN", "PFNb"];
    ($rv,@list) = $rls->globus_rls_client_lrc_add_bulk($lfnpfnlist);
    while ( $anerror = shift(@list) and defined($anerror)) {
      foreach $key ("STR2.S1", "STR2.S2", "ERRMSG", "RC") {
        print $key," : ",$anerror->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_add_bulk (globus_rls_handle_t *h, globus_list_t *str2_list, globus_list_t **str2bulk_list)
sub globus_rls_client_lrc_add_bulk() {
  my $self = shift;
  my $lfnpfnlist = shift;

  return _globus_rls_client_lrc_add_bulk($self->{handle},$lfnpfnlist);
}

=pod

=item B<globus_rls_client_lrc_clear()>

Clear all mappings from LRC database. User needs both ADMIN and LRCUPDATE privileges to perform this operation. Note that if the LRC is cleared this will not be reflected in any RLI servers updated by the LRC until the next softstate update, even if immediate updates are enabled.

No input parameter is required.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_clear();

=cut

#globus_result_t 	globus_rls_client_lrc_clear (globus_rls_handle_t *h)
sub globus_rls_client_lrc_clear() {
  my $self = shift;

  return _globus_rls_client_lrc_clear($self->{handle});
}

=pod

=item B<globus_rls_client_lrc_create($lfn, $pfn)>

Create mapping between a LFN and PFN. LFN should not exist yet.

The $lfn is the name of an LFN (Logic File Name). The $pfn is the name of a PFN (Physical File Name).

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_create("MyLFN", "anewPFN");

=cut

#globus_result_t 	globus_rls_client_lrc_create (globus_rls_handle_t *h, char *lfn, char *pfn)
sub globus_rls_client_lrc_create() {
  my $self = shift;
  my $lfn = shift;
  my $pfn = shift;

  return _globus_rls_client_lrc_create($self->{handle},$lfn,$pfn);
}

=pod

=item B<globus_rls_client_lrc_create_bulk(\@lfnpfnlist)>

Bulk create LFN,PFN mappings in LRC database.

The \@lfnpfnlist is reference to array containing the name of an LFN (Logical File Name) and the name of a PFN (Physical File Name) one ofter the other.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing failed updates. Keys to hashes are "STR2.S1" containing LFN, "STR2.S2" containing PFN, "ERRMSG" containing error message and "RC" containing result code.

B<Example:>

    $lfnpfnlist = ["MyLFN", "PFNa", "MyOtherLFN", "PFNa"];
    ($rv,@list) = $rls->globus_rls_client_lrc_create_bulk($lfnpfnlist);
    while ( $anerror = shift(@list) and defined($anerror)) {
      foreach $key ("STR2.S1", "STR2.S2", "ERRMSG", "RC") {
        print $key," : ",$anerror->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_create_bulk (globus_rls_handle_t *h, globus_list_t *str2_list, globus_list_t **str2bulk_list)
sub globus_rls_client_lrc_create_bulk() {
  my $self = shift;
  my $lfnpfnlist = shift;

  return _globus_rls_client_lrc_create_bulk($self->{handle},$lfnpfnlist);
}

=pod

=item B<globus_rls_client_lrc_delete($lfn, $pfn)>

Delete mapping between LFN and PFN.

The $lfn is the name of an LFN (Logic File Name) previously created with L<globus_rls_client_lrc_create()>. The $pfn is the name of a PFN (Physical File Name).

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_delete("MyLFN", "aPFN");

=cut

#globus_result_t 	globus_rls_client_lrc_delete (globus_rls_handle_t *h, char *lfn, char *pfn)
sub globus_rls_client_lrc_delete() {
  my $self = shift;
  my $lfn = shift;
  my $pfn = shift;

  return _globus_rls_client_lrc_delete($self->{handle},$lfn,$pfn);
}

=pod

=item B<globus_rls_client_lrc_delete_bulk(\@lfnpfnlist)>

Bulk delete LFN,PFN mappings in LRC database.

The \@lfnpfnlist is reference to array containing the name of an LFN (Logical File Name) and the name of a PFN (Physical File Name) one ofter the other.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing failed updates. Keys to hashes are "STR2.S1" containing LFN, "STR2.S2" containing PFN, "ERRMSG" containing error message and "RC" containing result code.

B<Example:>

    $lfnpfnlist = ["MyLFN", "PFNa", "MyLFN", "PFNb", "MyOtherLFN", "PFNa"];
    ($rv,@list) = $rls->globus_rls_client_lrc_delete_bulk($lfnpfnlist);
    while ( $anerror = shift(@list) and defined($anerror)) {
      foreach $key ("STR2.S1", "STR2.S2", "ERRMSG", "RC") {
        print $key," : ",$anerror->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_delete_bulk (globus_rls_handle_t *h, globus_list_t *str2_list, globus_list_t **str2bulk_list)
sub globus_rls_client_lrc_delete_bulk() {
  my $self = shift;
  my $lfnpfnlist = shift;

  return _globus_rls_client_lrc_delete_bulk($self->{handle},$lfnpfnlist);
}

=pod

=item B<globus_rls_client_lrc_exists($object, $objtype)>

Check if an object exists in the LRC database.

The $object is the name of an LFN (Logic File Name) or PFN (Physical File Name) previously created with L<globus_rls_client_lrc_create()>. The $objtype can be one of "globus_rls_obj_lrc_lfn" or "globus_rls_obj_lrc_pfn" constants.

B<Return value:>
    $rv is 0, if exists. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_exists("MyLFN","globus_rls_obj_lrc_lfn");

=cut

#globus_result_t 	globus_rls_client_lrc_exists (globus_rls_handle_t *h, char *key, globus_rls_obj_type_t objtype)
sub globus_rls_client_lrc_exists() {
  my $self = shift;
  my $object = shift;
  my $objtype = shift;

  return _globus_rls_client_lrc_exists($self->{handle},$object,$objtype);
}

=pod

=item B<globus_rls_client_lrc_get_lfn($pfn, $offset, $reslimit)>

Return LFNs mapped to PFN in the LRC database.

The $pfn is the name of a PFN (Physical File Name).

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes with existing LFN - PFN mapping. Keys to hashes are "S1" containing LFN and "S2" containing PFN.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_lrc_get_lfn("aPFN", 0, 0);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("S1", "S2") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_get_lfn (globus_rls_handle_t *h, char *pfn, int *offset, int reslimit, globus_list_t **str2_list)
sub globus_rls_client_lrc_get_lfn() {
  my $self = shift;
  my $pfn = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_lrc_get_lfn($self->{handle},$pfn,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_lrc_get_lfn_bulk(\@pfnlist)>

Bulk return LFNs mapped to PFN in the LRC database.

The \@pfnlist is a reference to array containing the name of PFNs (Physical File Name) one ofter the other.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes with LFN - PFN mapping, if exists. It contains error value and error message, if PFN does not exists. Keys to hashes are "STR2.S1" containing LFN, "STR2.S2" containing PFN, "RC" containing result code (0 means PFN found) and "ERRMSG" containing error message (if RC is not equal to 0).

B<Example:>

    $pfnlist = ["aPFN", "otherPFN", "anotherPFN"];
    ($rv, @list) = $rls->globus_rls_client_lrc_get_lfn_bulk($pfnlist);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("STR2.S1", "STR2.S2", "RC", "ERRMSG") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_get_lfn_bulk (globus_rls_handle_t *h, globus_list_t *pfnlist, globus_list_t **str2bulk_list)
sub globus_rls_client_lrc_get_lfn_bulk() {
  my $self = shift;
  my $pfnlist = shift;

  return _globus_rls_client_lrc_get_lfn_bulk($self->{handle},$pfnlist);
}

=pod

=item B<globus_rls_client_lrc_get_lfn_wc($pattern, $pattern_type, $offset, $reslimit)>

Return LFNs mapped to wildcarded PFN in the LRC database.

The $pattern is the string containing a pattern to search for. The $pattern_type can be one of the "rls_pattern_unix" or "rls_pattern_sql" string contants. The pattern type identifies wildcard characters used in $pattern. Wildcard chars can be Unix file globbing chars (* matches 0 or more characters, ? matches any single character) or SQL "like" wildcard characters (% matches 0 or more charactes, _ matches any single character).

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes with existing LFN - PFN mapping. Keys to hashes are "S1" containing LFN and "S2" containing PFN.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_lrc_get_lfn_wc("*PFN","rls_pattern_unix", 0, 0);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("S1", "S2") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_get_lfn_wc (globus_rls_handle_t *h, char *pfn_pattern, globus_rls_pattern_t type, int *offset, int reslimit, globus_list_t **str2_list)
sub globus_rls_client_lrc_get_lfn_wc() {
  my $self = shift;
  my $pfn_pattern = shift;
  my $type = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_lrc_get_lfn_wc($self->{handle},$pfn_pattern,$type,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_lrc_get_pfn($lfn, $offset, $reslimit)>

Return PFNs mapped to LFN in the LRC database.

The $lfn is the name of an LFN (Logical File Name).

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes with existing LFN - PFN mapping. Keys to hashes are "S1" containing LFN and "S2" containing PFN.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_lrc_get_pfn("MyLFN", 0, 0);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("S1", "S2") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_get_pfn (globus_rls_handle_t *h, char *lfn, int *offset, int reslimit, globus_list_t **str2_list)
sub globus_rls_client_lrc_get_pfn() {
  my $self = shift;
  my $lfn = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_lrc_get_pfn($self->{handle},$lfn,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_lrc_get_pfn_bulk(\@lfnlist)>

Bulk return PFNs mapped to LFN in the LRC database.

The \@lfnlist is reference to array containing the names of LFNs (Logical File Name).

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes with LFN - PFN mapping, if exists. It contains error value and error message, if LFN does not exists. Keys to hashes are "STR2.S1" containing LFN, "STR2.S2" containing PFN, "RC" containing result code (0 means LFN found) and "ERRMSG" containing error message (if RC is not equal to 0).

B<Example:>

    $lfnlist = ["anLFN", "otherLFN", "anotherLFN"];
    ($rv, @list) = $rls->globus_rls_client_lrc_get_pfn_bulk($lfnlist);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("STR2.S1", "STR2.S2", "RC", "ERRMSG") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_get_pfn_bulk (globus_rls_handle_t *h, globus_list_t *lfnlist, globus_list_t **str2bulk_list)
sub globus_rls_client_lrc_get_pfn_bulk() {
  my $self = shift;
  my $lfnlist = shift;

  return _globus_rls_client_lrc_get_pfn_bulk($self->{handle},$lfnlist);
}

=pod

=item B<globus_rls_client_lrc_get_pfn_wc($pattern, $pattern_type, $offset, $reslimit)>

Return PFNs mapped to wildcarded LFN in the LRC database.

The $pattern is the string containing a pattern to search for. The $pattern_type can be one of the "rls_pattern_unix" or "rls_pattern_sql" string contants. The pattern type identifies wildcard characters used in $pattern. Wildcard chars can be Unix file globbing chars (* matches 0 or more characters, ? matches any single character) or SQL "like" wildcard characters (% matches 0 or more charactes, _ matches any single character).

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes with existing LFN - PFN mapping. Keys to hashes are "S1" containing LFN and "S2" containing PFN.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_lrc_get_pfn_wc("\%LFN", "rls_pattern_sql", 0, 0);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("S1", "S2") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_get_pfn_wc (globus_rls_handle_t *h, char *lfn_pattern, globus_rls_pattern_t type, int *offset, int reslimit, globus_list_t **str2_list)
sub globus_rls_client_lrc_get_pfn_wc() {
  my $self = shift;
  my $pattern = shift;
  my $pattern_type = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_lrc_get_pfn_wc($self->{handle},$pattern,$pattern_type,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_lrc_mapping_exists($lfn, $pfn)>

Check if a mapping exists in the LRC database.

The $lfn is the name of an LFN (Logic File Name) previously created with L<globus_rls_client_lrc_create()>. The $pfn is the name of a PFN (Physical File Name).

B<Return value:>
    $rv is 0, if exists. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_mapping_exists("MyLFN","aPFN");

=cut

#globus_result_t 	globus_rls_client_lrc_mapping_exists (globus_rls_handle_t *h, char *lfn, char *pfn)
sub globus_rls_client_lrc_mapping_exists() {
  my $self = shift;
  my $lfn = shift;
  my $pfn = shift;

  return _globus_rls_client_lrc_mapping_exists($self->{handle},$lfn,$pfn);
}

=pod

=item B<globus_rls_client_lrc_rli_add($rli_url, $flags, $pattern)>

LRC servers send information about LFNs in their database to the the list of RLI servers in the database, added with the following function. Updates may be partitioned amongst multiple RLIs by specifying one or more patterns for an RLI.

The $rli_url is an URL of RLI server that LRC should send updates to. The $flags should be zero. The $pattern is used to filter which LFNs are sent to rli_url. Standard Unix wildcard characters (*, ?) may be used to do wildcard matches.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_rli_add("rls://rls_server.example.org", 0, "*");

=cut

#globus_result_t 	globus_rls_client_lrc_rli_add (globus_rls_handle_t *h, char *rli_url, int flags, char *pattern)
sub globus_rls_client_lrc_rli_add() {
  my $self = shift;
  my $rli_url = shift;
  my $flags = shift;
  my $pattern = shift;

  return _globus_rls_client_lrc_rli_add($self->{handle},$rli_url,$flags,$pattern);
}

=pod

=item B<globus_rls_client_lrc_rli_delete($rli_url, $pattern)>

Delete an entry from the LRC rli/partition tables.

The $rli_url is an URL of RLI server to remove from LRC partition table. The $pattern is used to specify which rli_url/pattern is removed. Standard Unix wildcard characters (*, ?) may be used to do wildcard matches.

B<Return value:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_lrc_rli_delete("rls://rls_server.example.org", "*");

=cut

#globus_result_t 	globus_rls_client_lrc_rli_delete (globus_rls_handle_t *h, char *rli_url, char *pattern)
sub globus_rls_client_lrc_rli_delete() {
  my $self = shift;
  my $rli_url = shift;
  my $pattern = shift;

  return _globus_rls_client_lrc_rli_delete($self->{handle},$rli_url,$pattern);
}

=pod

=item B<globus_rls_client_lrc_rli_get_part($rli_url, $pattern)>

Get RLI update partitions from LRC server.

The $rli_url identifies RLI that partition data will be retrieved for. The $pattern is used to filter partitions. Standard Unix wildcard characters (*, ?) may be used to do wildcard matches.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing partitions. Keys to hashes are "S1" containing RLI_URL and "S2" containing pattern used to partition updates.

B<Example:>

    ($rv, @list) = $rls->globus_rls_client_lrc_rli_get_part("rls://rls_server.example.org", "*");
    while ( $rli = shift(@list) and defined($rli)) {
      foreach $key ("S1","S2") {
        print $key," : ",$rli->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_rli_get_part (globus_rls_handle_t *h, char *rli_url, char *pattern, globus_list_t **str2_list)
sub globus_rls_client_lrc_rli_get_part() {
  my $self = shift;
  my $rli_url = shift;
  my $pattern = shift;

  return _globus_rls_client_lrc_rli_get_part($self->{handle},$rli_url,$pattern);
}

=pod

=item B<globus_rls_client_lrc_rli_info($rli_url)>

Get info about RLI server updated by an LRC server.

The $rli_url is an URL of RLI server to retrieve info for.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $info with the reference to a hash containing information on the specified rli. Keys to the hash are "URL" containing rli url, "FLAGS" containing pattern used to partition updates, "LASTUPDATE" containing the time of last softstate update and "UPDATEINTERVAL" containing the interval between softstate updates.

B<Example:>

    ($rv, $info) = $rls->globus_rls_client_lrc_rli_info("rls://rls_server.example.org");
    foreach $key ("URL","FLAGS", "LASTUPDATE", "UPDATEINTERVAL") {
      print $key," : ",$info->{$key},"\n"; }

=cut

#globus_result_t 	globus_rls_client_lrc_rli_info (globus_rls_handle_t *h, char *rli_url, globus_rls_rli_info_t *info)
sub globus_rls_client_lrc_rli_info() {
  my $self = shift;
  my $rli_url = shift;

  return _globus_rls_client_lrc_rli_info($self->{handle},$rli_url);
}

=pod

=item B<globus_rls_client_lrc_rli_list()>

Return URLs of RLIs that LRC sends updates to.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing information on rlis. Keys to hashes are "URL" containing rli url, "FLAGS" containing pattern used to partition updates, "LASTUPDATE" containing the time of last softstate update and "UPDATEINTERVAL" containing the interval between softstate updates.

B<Example:>

    ($rv, @list) = $rls->globus_rls_client_lrc_rli_list();
    while ( $rli = shift(@list) and defined($rli)) {
      foreach $key ("URL","FLAGS", "LASTUPDATE", "UPDATEINTERVAL") {
        print $key," : ",$rli->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_lrc_rli_list (globus_rls_handle_t *h, globus_list_t **rliinfo_list)
sub globus_rls_client_lrc_rli_list() {
  my $self = shift;

  return _globus_rls_client_lrc_rli_list($self->{handle});
}

#######################################################################
#######################################################################
# RLI Operations
#

=pod

=back

=head2 RLI Operations

=over 4

=item B<globus_rls_client_rli_exists($object, $objtype)>

Check if an object exists in the RLI database.

The $object is the name of an LFN (Logic File Name) previously created with L<globus_rls_client_lrc_create()> or the name of an LRC. The $objtype can be one of "globus_rls_obj_rli_lrc" or "globus_rls_obj_rli_lfn" constants, signing the type of $object.

B<Return value:>
    $rv is 0, if exists. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_rli_exists("MyLFN","globus_rls_obj_rli_lfn");
    OR
    $rv = $rls->globus_rls_client_rli_exists("rls://rls_server.example.org:39281","globus_rls_obj_rli_lrc");

=cut

#globus_result_t 	globus_rls_client_rli_exists (globus_rls_handle_t *h, char *key, globus_rls_obj_type_t objtype)
sub globus_rls_client_rli_exists() {
  my $self = shift;
  my $object = shift;
  my $objtype = shift;

  return _globus_rls_client_rli_exists($self->{handle},$object,$objtype);
}

=pod

=item B<globus_rls_client_rli_get_lrc($lfn, $offset, $reslimit)>

Return LRCs mapped to LFN in the RLI database.

The $lfn is the name of an LFN (Logical File Name) whose list of LRCs is desired.

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes with existing LFN - LRC mapping. Keys to hashes are "S1" containing LFN and "S2" containing an LRC that $lfn maps to.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_rli_get_lrc("MyLFN", 0, 0);
    while ( $lrc = shift(@list) and defined($lrc)) {
      foreach $key ("S1", "S2") {
        print $key," : ",$lrc->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_rli_get_lrc (globus_rls_handle_t *h, char *lfn, int *offset, int reslimit, globus_list_t **str2_list)
sub globus_rls_client_rli_get_lrc() {
  my $self = shift;
  my $lfn = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_rli_get_lrc($self->{handle},$lfn,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_rli_get_lrc_bulk(\@lfnlist)>

Bulk return LRCs mapped to LFN in the RLI database.

The \@lfnlist is reference to array containing the names of LFNs (Logical File Name).

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes with existing LFN - LRC mapping. Keys to hashes are "STR2.S1" containing LFN, "STR2.S2" containing an LRC that $lfn maps to, "RC" containing result code (0 means mapping found) and "ERRMSG" containing error message (when rc is not zero).

B<Example:>

    $lfnlist = ["anLFN", "otherLFN", "anotherLFN"];
    ($rv, @list) = $rls->globus_rls_client_rli_get_lrc_bulk($lfnlist);
    while ( $pair = shift(@list) and defined($pair)) {
      foreach $key ("STR2.S1", "STR2.S2", "RC", "ERRMSG") {
        print $key," : ",$pair->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_rli_get_lrc_bulk (globus_rls_handle_t *h, globus_list_t *lfnlist, globus_list_t **str2bulk_list)
sub globus_rls_client_rli_get_lrc_bulk() {
  my $self = shift;
  my $lfnlist = shift;

  return _globus_rls_client_rli_get_lrc_bulk($self->{handle},$lfnlist);
}

=pod

=item B<globus_rls_client_rli_get_lrc_wc($pattern, $pattern_type, $offset, $reslimit)>

Return LRCs mapped to wildcarded LFN in the RLI database.

The $pattern is the string containing an LFN pattern to search for. The $pattern_type can be one of the "rls_pattern_unix" or "rls_pattern_sql" string contants. The pattern type identifies wildcard characters used in $pattern. Wildcard chars can be Unix file globbing chars (* matches 0 or more characters, ? matches any single character) or SQL "like" wildcard characters (% matches 0 or more charactes, _ matches any single character).

$offset is offset into result list. Used in conjunction with reslimit to retrieve results a few at a time. Use 0 to begin with first result. $reslimit is the maximum number of results to return. Used in conjunction with offset to retrieve results a few at a time. Use 0 to retrieve all results.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    $offset as explained above.
    @list with the list of references to hashes with LRCs that map to $pattern. Keys to hashes are "S1" containing LFN and "S2" containing the LRC it maps to.

B<Example:>

    ($rv, $offset, @list) = $rls->globus_rls_client_rli_get_lrc_wc("*LFN","rls_pattern_unix", 0, 0);
    while ( $lrc = shift(@list) and defined($lrc)) {
      foreach $key ("S1", "S2") {
        print $key," : ",$lrc->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_rli_get_lrc_wc (globus_rls_handle_t *h, char *lfn_pattern, globus_rls_pattern_t type, int *offset, int reslimit, globus_list_t **str2_list)
sub globus_rls_client_rli_get_lrc_wc() {
  my $self = shift;
  my $pattern = shift;
  my $pattern_type = shift;
  my $offset = shift;
  my $reslimit = shift;

  return _globus_rls_client_rli_get_lrc_wc($self->{handle},$pattern,$pattern_type,$offset,$reslimit);
}

=pod

=item B<globus_rls_client_rli_lrc_list()>

Get list of LRCs updating this RLI server. Similar to globus_rls_client_rli_get_part() except no partition information is returned, just the LRC URLs.

B<Return values:>
    $rv is 0, if successful. Otherwise, a value greater than 0 in $rv is returned.
    @list with the list of references to hashes containing information on rlis. Keys to hashes are "URL" containing rli url and "LASTUPDATE" containing the time of last softstate update.

B<Example:>

    ($rv, @list) = $rls->globus_rls_client_rli_lrc_list();
    while ( $lrc = shift(@list) and defined($lrc)) {
      foreach $key ("URL", "LASTUPDATE") {
        print $key," : ",$lrc->{$key},"\n"; } }

=cut

#globus_result_t 	globus_rls_client_rli_lrc_list (globus_rls_handle_t *h, globus_list_t **lrcinfo_list)
sub globus_rls_client_rli_lrc_list() {
  my $self = shift;

  return _globus_rls_client_rli_lrc_list($self->{handle});
}

=pod

=item B<globus_rls_client_rli_mapping_exists($lfn, $lrc)>

Check if a mapping exists in the RLI database.

The $lfn is the name of an LFN (Logic File Name) previously created with L<globus_rls_client_lrc_create()>. The $lrc is the url of an LRC.

B<Return value:>
    $rv is 0, if exists. Otherwise, a value greater than 0 in $rv is returned.

B<Example:>

    $rv = $rls->globus_rls_client_rli_mapping_exists("MyLFN","rls://rls_server.example.org:39281");

=cut

#globus_result_t 	globus_rls_client_rli_mapping_exists (globus_rls_handle_t *h, char *lfn, char *lrc)
sub globus_rls_client_rli_mapping_exists() {
  my $self = shift;
  my $lfn = shift;
  my $lrc = shift;

  return _globus_rls_client_rli_mapping_exists($self->{handle},$lfn,$lrc)
}

#######################################################################
#######################################################################
# Destructor/Deactivation
#
sub DESTROY {
  my $rls = @_;
  _globus_module_deactivate_rls_client();
  _globus_module_deactivate_io();
  _globus_module_deactivate_common();
#  print "Destroying RLS package\n";
}

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__

=back

=cut

#=head1 SEE ALSO
#
#Mention other useful documentation such as the documentation of
#related modules or operating system documentation (such as man pages
#in UNIX), or any relevant external documentation such as RFCs or
#standards.
#
#If you have a mailing list set up for your module, mention it here.
#
#If you have a web site set up for your module, mention it here.

=pod

=head1 AUTHOR

Jozsef Kovacs, E<lt>Jozsef.Kovacs@cern.chE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (c) Members of the EGEE Collaboration. 2004.
See http://public.eu-egee.org/partners/ for details on the copyright
holders.
For license conditions see the license file or
http://www.eu-egee.org/license.html

=cut
