#!/usr/bin/perl -w

#Copyright (c) Members of the EGEE Collaboration. 2004.
#See http://public.eu-egee.org/partners/ for details on the copyright holders.
#For license conditions see the license file or
#http://www.eu-egee.org/license.html

# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl lrc_advance.t'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test::More tests => 19;
use strict;
use warnings;
use ExtUtils::testlib;

BEGIN { use_ok('Globus::RLS') }

my ($lfn,$lfn2,$pfn) = ("t1", "t2");
my ($rv,$offset,$tmp);
my @hashlist;
my ($globus_rls_obj_type,$globus_rls_pat_type);
my ($lfnpfnlist,$lfnlist,$pfnlist);

die "Please set GLOBUS_RLS_SERVER!\n" unless exists($ENV{GLOBUS_RLS_SERVER});
my $endpoint = $ENV{GLOBUS_RLS_SERVER};
printf("\nUsing GLOUS RLS SERVER: %s\n",$endpoint);

#######################################################################
#######################################################################
# Hash formatter and printer method
#

sub print_hash($$$) {
  my ($title,$preline,$hash) = (shift,shift,shift);
  my $key;
  printf("%s\n",$title);
  foreach $key (keys (%$hash)) {
	printf("%s%s : %s\n",$preline,$key,$hash->{$key});  
  }
}

sub print_list_of_hash($$$@) {
  my ($maintitle,$subtitle,$preline,@hashlist) = (shift,shift,shift,@_);
  my ($key,$tmp,$counter);

  printf("%s\n",$maintitle);
  ($tmp,$counter) = (shift(@hashlist),1);
  printf("%sEmpty list!\n",$preline) unless defined($tmp);
  while ( defined($tmp) ) {
	print_hash(sprintf("%s [%i]",$subtitle,$counter),$preline,$tmp);
	$counter++; $tmp = shift(@hashlist);
  }
}

#########################
#
# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.


printf("\n== RLS NEW ==\n");
my $rls = Globus::RLS->new();
ok(1,'rls->new()');

printf("\n== GET TIMEOUT ==\n");
$tmp = $rls->globus_rls_client_get_timeout();
ok(1,'$seconds = rls->globus_rls_client_get_timeout() = '.$tmp);

printf("\n== SET TIMEOUT ==\n");
$rls->globus_rls_client_set_timeout($tmp*=2);
ok(1,'rls->globus_rls_client_get_timeout('.$tmp.');');

printf("\n== CONNECT ==\n");
$rls->globus_rls_client_connect($endpoint);
ok(1,'rls->globus_rls_client_connect('.$endpoint.')');

printf("\n== CREATE ==\n");
($rv) = $rls->globus_rls_client_lrc_create($lfn,$pfn="0");
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create("'.$lfn.'","'.$pfn.'") = '.$rv);
($rv) = $rls->globus_rls_client_lrc_create($lfn2,$pfn);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create("'.$lfn2.'","'.$pfn.'") = '.$rv);

printf("\n== ADD ==\n");
for($pfn=1;$pfn<=2;$pfn++) {
($rv) = $rls->globus_rls_client_lrc_add($lfn,$pfn);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_add("'.$lfn.'","'.$pfn.'") = '.$rv); }

printf("\n== MAPPING EXISTS ==\n");
($rv) = $rls->globus_rls_client_lrc_mapping_exists($lfn,$pfn="0");
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_mapping_exists("'.$lfn.'","'.$pfn.'") = '.$rv);

printf("\n== MAPPING EXISTS == (should fail)\n");
($rv) = $rls->globus_rls_client_lrc_mapping_exists($lfn,$pfn=$lfn2);
ok($rv != 0,'$rv = $rls->globus_rls_client_lrc_mapping_exists("'.$lfn.'","'.$pfn.'") = '.$rv);

printf("\n== EXISTS ==\n");
$globus_rls_obj_type = "globus_rls_obj_lrc_lfn";
($rv) = $rls->globus_rls_client_lrc_exists($lfn,$globus_rls_obj_type);
ok($rv eq 0,'$rv = rls->globus_rls_client_lrc_exists("'.$lfn.'","'.$globus_rls_obj_type.'") = '.$rv);

printf("\n== EXISTS == (should fail)\n");
$globus_rls_obj_type = "globus_rls_obj_lrc_pfn";
($rv) = $rls->globus_rls_client_lrc_exists($lfn,$globus_rls_obj_type);
ok($rv != 0,'$rv = rls->globus_rls_client_lrc_exists("'.$lfn.'","'.$globus_rls_obj_type.'") = '.$rv);

printf("\n== GET LFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_unix";
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_get_lfn_wc($pfn="*",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_lfn_wc("'.$pfn.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== GET LFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_sql";
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_get_lfn_wc($pfn="0\%",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_lfn_wc("'.$pfn.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== GET PFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_unix";
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_get_pfn_wc($tmp="*t*",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_pfn_wc("'.$tmp.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== GET PFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_sql";
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_get_pfn_wc($tmp="\%2",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_pfn_wc("'.$tmp.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== CLEAR ==\n");
($rv) = $rls->globus_rls_client_lrc_clear();
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_clear() = '.$rv);

printf("\n== CLOSE ==\n");
$rls->globus_rls_client_close();
ok(1,'$rls->globus_rls_client_close()');


