#!/usr/bin/perl -w

#Copyright (c) Members of the EGEE Collaboration. 2004.
#See http://public.eu-egee.org/partners/ for details on the copyright holders.
#For license conditions see the license file or
#http://www.eu-egee.org/license.html

# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl lrc_attr.t'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test::More tests => 28;
use strict;
use warnings;
use ExtUtils::testlib;

BEGIN { use_ok('Globus::RLS') }

my ($lfn,$lfn2) = ("logic1", "logic2");
my ($pfn,$pfn2) = ("file1", "file2");
my ($rv,$offset);
my @hashlist;
my $globus_rls_pat_type;
my ($object,$val);
my ($attrname,$objtype,$attrtype,$opstr);
my ($clearvalues);

die "Please set GLOBUS_RLS_SERVER!\n" unless exists($ENV{GLOBUS_RLS_SERVER});
my $endpoint = $ENV{GLOBUS_RLS_SERVER};
printf("\nUsing GLOUS RLS SERVER: %s\n",$endpoint);

#######################################################################
#######################################################################
# Hash formatter and printer method
#

sub print_hash($$$) {
  my ($title,$preline,$hash) = (shift,shift,shift);
  my $key;
  printf("%s\n",$title);
  foreach $key (keys (%$hash)) {
	printf("%s%s : %s\n",$preline,$key,$hash->{$key});  
  }
}

sub print_list_of_hash($$$@) {
  my ($maintitle,$subtitle,$preline,@hashlist) = (shift,shift,shift,@_);
  my ($key,$tmp,$counter);

  printf("%s\n",$maintitle);
  ($tmp,$counter) = (shift(@hashlist),1);
  printf("%sEmpty list!\n",$preline) unless defined($tmp);
  while ( defined($tmp) ) {
	print_hash(sprintf("%s [%i]",$subtitle,$counter),$preline,$tmp);
	$counter++; $tmp = shift(@hashlist);
  }
}

#########################
#
# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.


printf("\n== RLS NEW && CONNECT ==\n");
my $rls = Globus::RLS->new();
ok(1,'rls->new()');
$rls->globus_rls_client_connect($endpoint);
ok(1,'rls->globus_rls_client_connect('.$endpoint.')');

printf("\n== CREATE && ADD ==\n");
($rv) = $rls->globus_rls_client_lrc_create($lfn,$pfn);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create("'.$lfn.'","'.$pfn.'") = '.$rv);
($rv) = $rls->globus_rls_client_lrc_create($lfn2,$pfn2);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create("'.$lfn2.'","'.$pfn2.'") = '.$rv);
($rv) = $rls->globus_rls_client_lrc_add($lfn,$pfn2);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_add("'.$lfn.'","'.$pfn2.'") = '.$rv);

printf("\n== GET LFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_unix";
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_get_lfn_wc($pfn="*",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_lfn_wc("'.$pfn.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR CREATE ==\n");
($attrname,$objtype,$attrtype) = ("size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int");
($rv) = $rls->globus_rls_client_lrc_attr_create($attrname,$objtype,$attrtype);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_create("'.$attrname.'","'.$objtype.'","'.$attrtype.'") = '.$rv);
($attrname,$objtype,$attrtype) = ("owner","globus_rls_obj_lrc_lfn","globus_rls_attr_type_str");
($rv) = $rls->globus_rls_client_lrc_attr_create($attrname,$objtype,$attrtype);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_create("'.$attrname.'","'.$objtype.'","'.$attrtype.'") = '.$rv);
($attrname,$objtype,$attrtype) = ("date","globus_rls_obj_lrc_lfn","globus_rls_attr_type_date");
($rv) = $rls->globus_rls_client_lrc_attr_create($attrname,$objtype,$attrtype);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_create("'.$attrname.'","'.$objtype.'","'.$attrtype.'") = '.$rv);

printf("\n== ATTR GET ==\n");
($attrname,$objtype) = ("size","globus_rls_obj_lrc_lfn");
($rv, @hashlist) = $rls->globus_rls_client_lrc_attr_get($attrname,$objtype);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_attr_get("'.$attrname.'","'.$objtype.'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
($attrname,$objtype) = ("","globus_rls_obj_lrc_lfn");
($rv, @hashlist) = $rls->globus_rls_client_lrc_attr_get($attrname,$objtype);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_attr_get("'.$attrname.'","'.$objtype.'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR ADD ==\n");
($object,$attrname,$objtype,$attrtype,$val) = ($lfn,"size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int",100);
($rv) = $rls->globus_rls_client_lrc_attr_add($object,$attrname,$objtype,$attrtype,$val);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_add("'.$object.'","'.$attrname.'","'.$objtype.'","'.$attrtype.'","'.$val.'") = '.$rv);
($object,$attrname,$objtype,$attrtype,$val) = ($lfn2,"size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int",200);
($rv) = $rls->globus_rls_client_lrc_attr_add($object,$attrname,$objtype,$attrtype,$val);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_add("'.$object.'","'.$attrname.'","'.$objtype.'","'.$attrtype.'","'.$val.'") = '.$rv);
($object,$attrname,$objtype,$attrtype,$val) = ($lfn,"date","globus_rls_obj_lrc_lfn","globus_rls_attr_type_date","2004-09-16 15:01:08");
($rv) = $rls->globus_rls_client_lrc_attr_add($object,$attrname,$objtype,$attrtype,$val);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_add("'.$object.'","'.$attrname.'","'.$objtype.'","'.$attrtype.'","'.$val.'") = '.$rv);

printf("\n== ATTR VALUE GET ==\n");
($object,$attrname,$objtype) = ($lfn,"","globus_rls_obj_lrc_lfn");
($rv, @hashlist) = $rls->globus_rls_client_lrc_attr_value_get($object,$attrname,$objtype);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_attr_value_get("'.$object.'","'.$attrname.'","'.$objtype.'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR MODIFY ==\n");
($object,$attrname,$objtype,$attrtype,$val) = ($lfn,"size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int",300);
($rv) = $rls->globus_rls_client_lrc_attr_modify($object,$attrname,$objtype,$attrtype,$val);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_modify("'.$object.'","'.$attrname.'","'.$objtype.'","'.$attrtype.'","'.$val.'") = '.$rv);

printf("\n== ATTR SEARCH ==\n");
($attrname,$objtype,$opstr,$attrtype,$val) = ("size","globus_rls_obj_lrc_lfn",">","globus_rls_attr_type_int",50);
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_attr_search($attrname,$objtype,$opstr,$attrtype,$val,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_attr_search("'.$attrname.'","'.$objtype.'","'.$opstr.'","'.$attrtype.'","'.$val.'","0","0") = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR SEARCH == (should fail)\n");
($attrname,$objtype,$opstr,$attrtype,$val) = ("xxxx","globus_rls_obj_lrc_lfn",">","globus_rls_attr_type_int",50);
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_attr_search($attrname,$objtype,$opstr,$attrtype,$val,0,0);
ok($rv != 0,'$rv $offset @list = rls->globus_rls_client_lrc_attr_search("'.$attrname.'","'.$objtype.'","'.$opstr.'","'.$attrtype.'","'.$val.'","0","0") = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR VALUE GET ==\n");
($object,$attrname,$objtype) = ($lfn,"","globus_rls_obj_lrc_lfn");
($rv, @hashlist) = $rls->globus_rls_client_lrc_attr_value_get($object,$attrname,$objtype);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_attr_value_get("'.$object.'","'.$attrname.'","'.$objtype.'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR REMOVE ==\n");
($object,$attrname,$objtype) = ($lfn,"size","globus_rls_obj_lrc_lfn");
($rv) = $rls->globus_rls_client_lrc_attr_remove($object,$attrname,$objtype);
ok($rv eq 0,'$rv = rls->globus_rls_client_lrc_attr_remove("'.$object.'","'.$attrname.'","'.$objtype.'") = '.$rv);

printf("\n== ATTR VALUE GET ==\n");
($object,$attrname,$objtype) = ($lfn,"","globus_rls_obj_lrc_lfn");
($rv, @hashlist) = $rls->globus_rls_client_lrc_attr_value_get($object,$attrname,$objtype);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_attr_value_get("'.$object.'","'.$attrname.'","'.$objtype.'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR DELETE == (should fail)\n");
($attrname,$objtype,$clearvalues) = ("size","globus_rls_obj_lrc_lfn",0);
($rv) = $rls->globus_rls_client_lrc_attr_delete($attrname,$objtype,$clearvalues);
ok($rv != 0,'$rv = rls->globus_rls_client_attr_delete("'.$attrname.'","'.$objtype.'","'.$clearvalues.'") = '.$rv);

printf("\n== ATTR DELETE ==\n");
($attrname,$objtype,$clearvalues) = ("size","globus_rls_obj_lrc_lfn",1);
($rv) = $rls->globus_rls_client_lrc_attr_delete($attrname,$objtype,$clearvalues);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_delete("'.$attrname.'","'.$objtype.'","'.$clearvalues.'") = '.$rv);
($attrname,$objtype,$clearvalues) = ("owner","globus_rls_obj_lrc_lfn",1);
($rv) = $rls->globus_rls_client_lrc_attr_delete($attrname,$objtype,$clearvalues);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_delete("'.$attrname.'","'.$objtype.'","'.$clearvalues.'") = '.$rv);
($attrname,$objtype,$clearvalues) = ("date","globus_rls_obj_lrc_lfn",1);
($rv) = $rls->globus_rls_client_lrc_attr_delete($attrname,$objtype,$clearvalues);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_delete("'.$attrname.'","'.$objtype.'","'.$clearvalues.'") = '.$rv);

printf("\n== CLEAR && CLOSE ==\n");
($rv) = $rls->globus_rls_client_lrc_clear();
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_clear() = '.$rv);
$rls->globus_rls_client_close();
ok(1,'$rls->globus_rls_client_close()');
