#!/usr/bin/perl -w

#Copyright (c) Members of the EGEE Collaboration. 2004.
#See http://public.eu-egee.org/partners/ for details on the copyright holders.
#For license conditions see the license file or
#http://www.eu-egee.org/license.html

# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl lrc_bulk.t'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test::More tests => 11;
use strict;
use warnings;
use ExtUtils::testlib;

BEGIN { use_ok('Globus::RLS') }

my ($lfn,$pfn) = ("t1", "f1");
my ($rv,$offset,$globus_rls_pat_type);
my (@outlist,@hashlist,$mylist);
my ($lfnpfnlist,$lfnlist,$pfnlist);
my ($attrname,$objtype,$attrtype);

die "Please set GLOBUS_RLS_SERVER!\n" unless exists($ENV{GLOBUS_RLS_SERVER});
my $endpoint = $ENV{GLOBUS_RLS_SERVER};
printf("\nUsing GLOUS RLS SERVER: %s\n",$endpoint);

#######################################################################
#######################################################################
# Hash formatter and printer method
#

sub print_hash($$$) {
  my ($title,$preline,$hash) = (shift,shift,shift);
  my $key;
  printf("%s\n",$title);
  foreach $key (keys (%$hash)) {
	printf("%s%s : %s\n",$preline,$key,$hash->{$key});  
  }
}

sub print_list_of_hash($$$@) {
  my ($maintitle,$subtitle,$preline,@hashlist) = (shift,shift,shift,@_);
  my ($key,$tmp,$counter);

  printf("%s\n",$maintitle);
  ($tmp,$counter) = (shift(@hashlist),1);
  printf("%sEmpty list!\n",$preline) unless defined($tmp);
  while ( defined($tmp) ) {
	print_hash(sprintf("%s [%i]",$subtitle,$counter),$preline,$tmp);
	$counter++; $tmp = shift(@hashlist);
  }
}

#########################
#
# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.

printf("\n== RLS NEW ==\n");
my $rls = Globus::RLS->new();
ok(1,'rls->new()');

printf("\n== CONNECT ==\n");
$rls->globus_rls_client_connect($endpoint);
ok(1,'rls->globus_rls_client_connect('.$endpoint.')');

printf("\n== CREATE BULK == (should partially fail)\n");
$lfnpfnlist = [$lfn,$pfn,"loga",$pfn,"logb",$pfn,"logb",$pfn];
($rv,@hashlist) = $rls->globus_rls_client_lrc_create_bulk($lfnpfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create_bulk("'.join("\",\"",@$lfnpfnlist).'") = '.$rv);
print_list_of_hash("   ::> List failures:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ADD BULK == (should partially fail)\n");
$lfnpfnlist = [$lfn,"a",$lfn,"b",$lfn,"b"];
($rv,@hashlist) = $rls->globus_rls_client_lrc_add_bulk($lfnpfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_add_bulk("'.join("\",\"",@$lfnpfnlist).'") = '.$rv);
print_list_of_hash("   ::> List of failures:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ATTR CREATE ==\n");
($attrname,$objtype,$attrtype) = ("size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int");
($rv) = $rls->globus_rls_client_lrc_attr_create($handle,$attrname,$objtype,$attrtype);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_create($handle,"'.$attrname.'","'.$objtype.'","'.$attrtype.'") = '.$rv);

#The following function is not working!
printf("\n== ATTR ADD BULK ==\n");
@strlist=("loga","size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int","100");
@strlist=(@strlist,"logb","size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int","200");
$rls->print_array("   ++> Input list content:","   ++> ",5,@strlist);
($rv,@strlist) = $rls->globus_rls_client_lrc_attr_add_bulk($handle,\@strlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_add_bulk($handle,@list) = '.$rv);
$rls->print_array("   ::> List of failures:","   ::> ",3,@strlist);

printf("\n== ATTR DELETE ==\n");
($attrname,$objtype) = ("size","globus_rls_obj_lrc_lfn");
($rv) = $rls->globus_rls_client_lrc_attr_delete($handle,$attrname,$objtype,1);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_delete($handle,"'.$attrname.'","'.$objtype.'","1") = '.$rv);

printf("\n== GET LFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_unix";
($rv,$offset,@hashlist) = $rls->globus_rls_client_lrc_get_lfn_wc($pfn="*",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_lfn_wc("'.$pfn.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== GET LFN BULK == (should partially fail)\n");
$pfnlist = ["a","b","s"];
($rv,@hashlist) = $rls->globus_rls_client_lrc_get_lfn_bulk($pfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_get_lfn_bulk("'.join("\",\"",@$pfnlist).'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== GET PFN BULK == (should partially fail)\n");
$lfnlist = ["t1","loga","sss"];
($rv,@hashlist) = $rls->globus_rls_client_lrc_get_pfn_bulk($lfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_get_pfn_bulk("'.join("\",\"",@$lfnlist).'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== DELETE BULK == (should partially fail)\n");
$lfnpfnlist = [$lfn,"a",$lfn,"b",$lfn,"b"];
($rv,@hashlist) = $rls->globus_rls_client_lrc_delete_bulk($lfnpfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_delete_bulk("'.join("\",\"",@$lfnpfnlist).'") = '.$rv);
print_list_of_hash("   ::> List of failures:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== CLEAR ==\n");
($rv) = $rls->globus_rls_client_lrc_clear();
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_clear() = '.$rv);

printf("\n== CLOSE ==\n");
$rls->globus_rls_client_close();
ok(1,'$rls->globus_rls_client_close()');









