#!/usr/bin/perl -w

#Copyright (c) Members of the EGEE Collaboration. 2004.
#See http://public.eu-egee.org/partners/ for details on the copyright holders.
#For license conditions see the license file or
#http://www.eu-egee.org/license.html

# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl lrc_basic.t'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test::More tests => 27;
use strict;
use warnings;
use ExtUtils::testlib;

BEGIN { use_ok('Globus::RLS') }

my ($lfn,$lfn2,$pfn) = ("t1", "t2");
my ($rv,$offseti,$offseto,$reslimit);
my @hashlist;
my ($lfnpfnlist,$lfnlist,$pfnlist);
my ($globus_rls_pat_type);
my ($object,$pattern,$type);
my ($attrname,$objtype,$opstr,$attrtype,$val);

die "Please set GLOBUS_RLS_SERVER!\n" unless exists($ENV{GLOBUS_RLS_SERVER});
my $endpoint = $ENV{GLOBUS_RLS_SERVER};
printf("\nUsing GLOUS RLS SERVER: %s\n",$endpoint);

#######################################################################
#######################################################################
# Hash formatter and printer method
#

sub print_hash($$$) {
  my ($title,$preline,$hash) = (shift,shift,shift);
  my $key;
  printf("%s\n",$title);
  foreach $key (keys (%$hash)) {
	printf("%s%s : %s\n",$preline,$key,$hash->{$key});  
  }
}

sub print_list_of_hash($$$@) {
  my ($maintitle,$subtitle,$preline,@hashlist) = (shift,shift,shift,@_);
  my ($key,$tmp,$counter);

  printf("%s\n",$maintitle);
  ($tmp,$counter) = (shift(@hashlist),1);
  printf("%sEmpty list!\n",$preline) unless defined($tmp);
  while ( defined($tmp) ) {
	print_hash(sprintf("%s [%i]",$subtitle,$counter),$preline,$tmp);
	$counter++; $tmp = shift(@hashlist);
  }
}

#########################
#
# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.

printf("\n== RLS NEW ==\n");
my $rls = Globus::RLS->new();
ok(1,'rls->new()');

printf("\n== CONNECT ==\n");
$rls->globus_rls_client_connect($endpoint);
ok(1,'rls->globus_rls_client_connect('.$endpoint.')');

printf("\n== CREATE BULK == \n");
$lfnpfnlist = [$lfn,$pfn="0",$lfn2,$pfn];
($rv,@hashlist) = $rls->globus_rls_client_lrc_create_bulk($lfnpfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create_bulk("'.join("\",\"",@$lfnpfnlist).'") = '.$rv);
print_list_of_hash("   ::> List of failures:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== ADD BULK == \n");
$lfnpfnlist = [$lfn,"1",$lfn,"2"];
($rv,@hashlist) = $rls->globus_rls_client_lrc_add_bulk($lfnpfnlist);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_add_bulk("'.join("\",\"",@$lfnpfnlist).'") = '.$rv);
print_list_of_hash("   ::> List of failures:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== GET_PFN with RESLIMIT=2 ==\n");
($offseto,$reslimit) = (0,2);
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_lrc_get_pfn($lfn,$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_pfn("'.
	 join("\",\"",$lfn,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== GET LFN with RESLIMIT=1 ==\n");
($offseto,$reslimit) = (0,1);
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_lrc_get_lfn($pfn="0",$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_lfn("'.
	 join("\",\"",$pfn,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== GET LFN WILDCARD with RESLIMIT=3 ==\n");
($offseto,$reslimit) = (0,3);
$globus_rls_pat_type = "rls_pattern_unix";
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_lrc_get_lfn_wc($pfn="*",$globus_rls_pat_type,$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_lfn_wc("'.
	 join("\",\"",$pfn,$globus_rls_pat_type,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== GET PFN WILDCARD with RESLIMIT=3 ==\n");
($offseto,$reslimit) = (0,3);
$globus_rls_pat_type = "rls_pattern_unix";
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_lrc_get_pfn_wc("*t*",$globus_rls_pat_type,$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_get_pfn_wc("'.
	 join("\",\"","*t*",$globus_rls_pat_type,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== RLI GET LRC with RESLIMIT=1 ==\n");
($offseto,$reslimit) = (0,3);
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_rli_get_lrc($lfn,$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = $rls->globus_rls_client_rli_get_lrc("'.
	 join("\",\"",$lfn,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== RLI GET LRC WC with RESLIMIT=1 ==\n");
($pattern,$type) = ("t*","rls_pattern_unix");
($offseto,$reslimit) = (0,1);
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_rli_get_lrc_wc($pattern,$type,$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = $rls->globus_rls_client_rli_get_lrc_wc("'.
	 join("\",\"",$pattern,$type,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== ATTR CREATE ==\n");
($attrname,$objtype,$attrtype) = ("size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int");
($rv) = $rls->globus_rls_client_lrc_attr_create($attrname,$objtype,$attrtype);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_create("'.$attrname.'","'.$objtype.'","'.$attrtype.'") = '.$rv);

printf("\n== ATTR ADD ==\n");
($object,$attrname,$objtype,$attrtype,$val) = ($lfn,"size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int",100);
($rv) = $rls->globus_rls_client_lrc_attr_add($object,$attrname,$objtype,$attrtype,$val);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_add("'.$object.'","'.$attrname.'","'.$objtype.'","'.$attrtype.'","'.$val.'") = '.$rv);
($object,$attrname,$objtype,$attrtype,$val) = ($lfn2,"size","globus_rls_obj_lrc_lfn","globus_rls_attr_type_int",200);
($rv) = $rls->globus_rls_client_lrc_attr_add($object,$attrname,$objtype,$attrtype,$val);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_add("'.$object.'","'.$attrname.'","'.$objtype.'","'.$attrtype.'","'.$val.'") = '.$rv);

printf("\n== ATTR SEARCH with RESLIMIT=1 ==\n");
($attrname,$objtype,$opstr,$attrtype,$val) = ("size","globus_rls_obj_lrc_lfn",">","globus_rls_attr_type_int",50);
($offseto,$reslimit) = (0,1);
do
{
  $offseti = $offseto;
  ($rv,$offseto,@hashlist) = $rls->globus_rls_client_lrc_attr_search($attrname,$objtype,$opstr,$attrtype,$val,$offseti,$reslimit);
  ok($rv eq 0,'$rv $offset @list = rls->globus_rls_client_lrc_attr_search("'.
	 join("\",\"",$attrname,$objtype,$opstr,$attrtype,$val,$offseti,$reslimit).'") = '.$rv.','.$offseto);
  print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);
}
while( $rv==0 and $offseto!=-1);

printf("\n== ATTR DELETE == \n");
($attrname,$objtype) = ("size","globus_rls_obj_lrc_lfn");
($rv) = $rls->globus_rls_client_lrc_attr_delete($attrname,$objtype,1);
ok($rv eq 0,'$rv = rls->globus_rls_client_attr_delete("'.$attrname.'","'.$objtype.'","1") = '.$rv);

printf("\n== CLEAR ==\n");
($rv) = $rls->globus_rls_client_lrc_clear();
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_clear() = '.$rv);

printf("\n== CLOSE ==\n");
$rls->globus_rls_client_close();
ok(1,'$rls->globus_rls_client_close()');
