#!/usr/bin/perl -w

#Copyright (c) Members of the EGEE Collaboration. 2004.
#See http://public.eu-egee.org/partners/ for details on the copyright holders.
#For license conditions see the license file or
#http://www.eu-egee.org/license.html

# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl rli.t'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test::More tests => 19;
use strict;
use warnings;
use ExtUtils::testlib;

BEGIN { use_ok('Globus::RLS') }

die "Please set GLOBUS_RLS_SERVER!\n" unless exists($ENV{GLOBUS_RLS_SERVER});
my $endpoint = $ENV{GLOBUS_RLS_SERVER};
printf("\nUsing GLOUS RLS SERVER: %s\n",$endpoint);

#######################################################################
#######################################################################
# Hash formatter and printer method
#

sub print_hash($$$) {
  my ($title,$preline,$hash) = (shift,shift,shift);
  my $key;
  printf("%s\n",$title);
  foreach $key (keys (%$hash)) {
	printf("%s%s : %s\n",$preline,$key,$hash->{$key});  
  }
}

sub print_list_of_hash($$$@) {
  my ($maintitle,$subtitle,$preline,@hashlist) = (shift,shift,shift,@_);
  my ($key,$tmp,$counter);

  printf("%s\n",$maintitle);
  ($tmp,$counter) = (shift(@hashlist),1);
  printf("%sEmpty list!\n",$preline) unless defined($tmp);
  while ( defined($tmp) ) {
	print_hash(sprintf("%s [%i]",$subtitle,$counter),$preline,$tmp);
	$counter++; $tmp = shift(@hashlist);
  }
}

#########################
#
# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.

my ($lfn,$lfn2) = ("t1", "t2");
my $pfn;
my ($rv,$offset);
my @hashlist;
my $globus_rls_pat_type;
my ($rli_url,$flags,$pattern);
my ($key,$objtype);
my ($type,$lrc);
my $lfnlist;

printf("\n== RLS NEW ==\n");
my $rls = Globus::RLS->new();
ok(1,'rls->new()');

printf("\n== CONNECT ==\n");
$rls->globus_rls_client_connect($endpoint);
ok(1,'rls->globus_rls_client_connect('.$endpoint.')');

printf("\n== CREATE ==\n");
($rv) = $rls->globus_rls_client_lrc_create($lfn,$pfn="0");
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create("'.$lfn.'","'.$pfn.'") = '.$rv);
($rv) = $rls->globus_rls_client_lrc_create($lfn2,$pfn);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_create("'.$lfn2.'","'.$pfn.'") = '.$rv);

printf("\n== GET LFN WILDCARD ==\n");
$globus_rls_pat_type = "rls_pattern_unix";
($rv,$offset,) = $rls->globus_rls_client_lrc_get_lfn_wc($pfn="*",$globus_rls_pat_type,0,0);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_get_lfn_wc("'.$pfn.'","'.$globus_rls_pat_type.'",0,0) = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== LRC RLI ADD ==\n");
($rli_url,$flags,$pattern) = ("rls://lxb1408.cern.ch",0,"*");
($rv) = $rls->globus_rls_client_lrc_rli_add($rli_url,$flags,$pattern);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_rli_add("'.$rli_url.'","'.$flags.'","'.$pattern.'") = '.$rv);

printf("\n== LRC RLI GET PART ==\n");
($rli_url,$pattern) = ("rls://lxb1408.cern.ch","*");
($rv,@hashlist) = $rls->globus_rls_client_lrc_rli_get_part($rli_url,$pattern);
ok($rv eq 0,'$rv @list = rls->globus_rls_client_lrc_rli_get_part("'.$rli_url.'","'.$pattern.'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== RLI EXISTS (LRC) ==\n");
$lrc = $hashlist[0]->{"S1"};
($key,$objtype) = ($lrc,"globus_rls_obj_rli_lrc");
($rv) = $rls->globus_rls_client_rli_exists($key,$objtype);
ok($rv eq 0,'$rv = $rls->globus_rls_client_rli_exists("'.$key.'","'.$objtype.'") = '.$rv);

printf("\n== RLI EXISTS (LFN) ==\n");
($key,$objtype) = ($lfn,"globus_rls_obj_rli_lfn");
($rv) = $rls->globus_rls_client_rli_exists($key,$objtype);
ok($rv eq 0,'$rv = $rls->globus_rls_client_rli_exists("'.$key.'","'.$objtype.'") = '.$rv);

printf("\n== RLI EXISTS (LFN) (should fail) ==\n");
($key,$objtype) = ("zzzz","globus_rls_obj_rli_lfn");
($rv) = $rls->globus_rls_client_rli_exists($key,$objtype);
ok($rv != 0,'$rv = $rls->globus_rls_client_rli_exists("'.$key.'","'.$objtype.'") = '.$rv);

printf("\n== RLI GET LRC ==\n");
($rv,$offset,@hashlist) = $rls->globus_rls_client_rli_get_lrc($lfn,0,0);
ok($rv eq 0,'$rv $offset @list = $rls->globus_rls_client_rli_get_lrc("'.$lfn.'","0","0") = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== RLI GET LRC WC ==\n");
($pattern,$type) = ("t*","rls_pattern_unix");
($rv,$offset,@hashlist) = $rls->globus_rls_client_rli_get_lrc_wc($pattern,$type,0,0);
ok($rv eq 0,'$rv $offset @list = $rls->globus_rls_client_rli_get_lrc_wc("'.$pattern.'","'.$type.'","0","0") = '.$rv.','.$offset);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== RLI LRC LIST ==\n");
($rv,@hashlist) = $rls->globus_rls_client_rli_lrc_list();
ok($rv eq 0,'$rv @list = $rls->globus_rls_client_rli_lrc_list() = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== RLI MAPPING EXISTS ==\n");
($rv) = $rls->globus_rls_client_rli_mapping_exists($lfn,$lrc);
ok($rv eq 0,'$rv = $rls->globus_rls_client_rli_mapping_exists("'.$lfn.'","'.$lrc.'") = '.$rv);

printf("\n== RLI GET LRC BULK ==\n");
$lfnlist = ["x","y","z",$lfn];
($rv, @hashlist) = $rls->globus_rls_client_rli_get_lrc_bulk($lfnlist);
ok($rv eq 0,'$rv @list = $rls->globus_rls_client_rli_get_lrc_bulk("'.join("\",\"",@$lfnlist).'") = '.$rv);
print_list_of_hash("   ::> List content:","     ::> Hash content:","       ::> ",@hashlist);

printf("\n== LRC RLI DELETE ==\n");
($rli_url,$pattern) = ($endpoint,"*");
($rv) = $rls->globus_rls_client_lrc_rli_delete($rli_url,$pattern);
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_rli_delete("'.$rli_url.'","'.$pattern.'") = '.$rv);

printf("\n== CLEAR ==\n");
($rv) = $rls->globus_rls_client_lrc_clear();
ok($rv eq 0,'$rv = $rls->globus_rls_client_lrc_clear() = '.$rv);

printf("\n== CLOSE ==\n");
$rls->globus_rls_client_close();
ok(1,'$rls->globus_rls_client_close()');

